==> dokuwiki-2012.10.13.tgz: dokuwiki/lib/plugins/acl/lang/de-informal/lang.php <==
<?php
/**
 * German (informal) language file
 *
 * @author Alexander Fischer <tbanus@os-forge.net>
 * @author Juergen Schwarzer <jschwarzer@freenet.de>
 * @author Marcel Metz <marcel_metz@gmx.de>
 * @author Matthias Schulte <dokuwiki@lupo49.de>
 * @author Christian Wichmann <nospam@zone0.de>
 * @author Pierre Corell <info@joomla-praxis.de>
 */
$lang['admin_acl']             = 'Zugangsverwaltung';
$lang['acl_group']             = 'Gruppe';
$lang['acl_user']              = 'Benutzer';
$lang['acl_perms']             = 'Rechte für';
$lang['page']                  = 'Seite';
$lang['namespace']             = 'Namensraum';
$lang['btn_select']            = 'Auswählen';
$lang['p_user_id']             = 'Benutzer <b class="acluser">%s</b> hat im Moment folgende Rechte auf der Seite <b class="aclpage">%s</b>: <i>%s</i>';
$lang['p_user_ns']             = 'Benutzer <b class="acluser">%s</b> hat momentan die folgenden Rechte im Namensraum <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Die Gruppenmitglieder <b class="aclgroup">%s</b> haben momentan die folgenden Rechte auf der Seite <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Die Mitglieder der Gruppe <b class="aclgroup">%s</b> haben gerade Zugriff in folgenden Namensräumen <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Bitte <b>gib einen Nutzer oder eine Gruppe</b> in das Formular ein, um die Berechtigungen der Seite <b class="aclpage">%s</b> anzusehen oder zu bearbeiten.';
$lang['p_choose_ns']           = 'Bitte <b>gib einen Nutzer oder eine Gruppe</b> in das Formular ein, um die Berechtigungen des Namenraumes <b class="aclpage">%s</b> anzusehen oder zu bearbeiten.';
$lang['p_inherited']           = 'Hinweis: Diese Rechte wurden nicht explizit gesetzt, sondern von anderen Gruppen oder übergeordneten Namensräumen geerbt.';
$lang['p_isadmin']             = 'Hinweis: Die gewählte Gruppe oder der Benutzer haben immer die vollen Rechte, weil sie als Superuser konfiguriert sind.';
$lang['p_include']             = 'Höhere Rechte schließen kleinere mit ein. Hochlade- und Löschrechte sind nur für Namensräume, nicht für Seiten.';
$lang['current']               = 'Momentane Zugriffsregeln';
$lang['where']                 = 'Seite/Namensraum';
$lang['who']                   = 'Benutzer/Gruppe';
$lang['perm']                  = 'Rechte';
$lang['acl_perm0']             = 'Keine';
$lang['acl_perm1']             = 'Lesen';
$lang['acl_perm2']             = 'Bearbeiten';
$lang['acl_perm4']             = 'Erstellen';
$lang['acl_perm8']             = 'Hochladen';
$lang['acl_perm16']            = 'Löschen';
$lang['acl_new']               = 'Neuen Eintrag zufügen';
$lang['acl_mod']               = 'Eintrag modifizieren';

==> dokuwiki-2015.08.10a.tgz: dokuwiki/lib/plugins/acl/lang/de-informal/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Alexander Fischer <tbanus@os-forge.net>
 * @author Juergen Schwarzer <jschwarzer@freenet.de>
 * @author Marcel Metz <marcel_metz@gmx.de>
 * @author Matthias Schulte <dokuwiki@lupo49.de>
 * @author Christian Wichmann <nospam@zone0.de>
 * @author Pierre Corell <info@joomla-praxis.de>
 * @author Frank Loizzi <contact@software.bacal.de>
 * @author Volker Bödker <volker@boedker.de>
 */
$lang['admin_acl']             = 'Zugangsverwaltung';
$lang['acl_group']             = 'Gruppe:';
$lang['acl_user']              = 'Benutzer:';
$lang['acl_perms']             = 'Rechte für';
$lang['page']                  = 'Seite';
$lang['namespace']             = 'Namensraum';
$lang['btn_select']            = 'Auswählen';
$lang['p_user_id']             = 'Benutzer <b class="acluser">%s</b> hat im Moment folgende Rechte auf der Seite <b class="aclpage">%s</b>: <i>%s</i>';
$lang['p_user_ns']             = 'Benutzer <b class="acluser">%s</b> hat momentan die folgenden Rechte im Namensraum <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Die Gruppenmitglieder <b class="aclgroup">%s</b> haben momentan die folgenden Rechte auf der Seite <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Die Mitglieder der Gruppe <b class="aclgroup">%s</b> haben gerade Zugriff in folgenden Namensräumen <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Bitte <b>gib einen Benutzer oder eine Gruppe</b> in das Formular ein, um die Berechtigungen der Seite <b class="aclpage">%s</b> anzusehen oder zu bearbeiten.';
$lang['p_choose_ns']           = 'Bitte <b>gib einen Benutzer oder eine Gruppe</b> in das Formular ein, um die Berechtigungen des Namenraumes <b class="aclpage">%s</b> anzusehen oder zu bearbeiten.';
$lang['p_inherited']           = 'Hinweis: Diese Rechte wurden nicht explizit gesetzt, sondern von anderen Gruppen oder übergeordneten Namensräumen geerbt.';
$lang['p_isadmin']             = 'Hinweis: Die gewählte Gruppe oder der Benutzer haben immer die vollen Rechte, weil sie als Superuser konfiguriert sind.';
$lang['p_include']             = 'Höhere Rechte schließen kleinere mit ein. Hochlade- und Löschrechte sind nur für Namensräume, nicht für Seiten.';
$lang['current']               = 'Momentane Zugriffsregeln';
$lang['where']                 = 'Seite/Namensraum';
$lang['who']                   = 'Benutzer/Gruppe';
$lang['perm']                  = 'Rechte';
$lang['acl_perm0']             = 'Keine';
$lang['acl_perm1']             = 'Lesen';
$lang['acl_perm2']             = 'Bearbeiten';
$lang['acl_perm4']             = 'Erstellen';
$lang['acl_perm8']             = 'Hochladen';
$lang['acl_perm16']            = 'Löschen';
$lang['acl_new']               = 'Neuen Eintrag zufügen';
$lang['acl_mod']               = 'Eintrag modifizieren';
